#! /usr/bin/env python
# -*- coding: iso-8859-15 -*-

"""

==============
ldap_biblio.py
==============

SYNOPSIS
========

::
 
  ldap_biblio.py

DESCRIPTION
===========

extract information from LDAP

.. only:: man

    Figure is visible on PDF and HTML documents only.

    .. only:: html or latex

       .. graphviz::

          digraph ldap_biblio {
                 ldaphost [shape=diamond,
                     fontname=Courier,
                     label='{ldap host}'

                 ldap_biblio [shape=box,
                     fontname=Courier,
                     color=blue,
                     URL="http://forge.ipsl.jussieu.fr/pulsation/browser/trunk/aeres/scripts/ldap_biblio.py",
                     label="${PROJECT}/aeres/scripts/ldap_biblio.py"];

                 {ldaphost} -> {ldap_biblio} -> {++}
             }

SEE ALSO
========

EXAMPLES
========

::

 ldap_biblio.py

TIPS
====

To install ldap for python on mac lion::

 sudo pip install --upgrade python-ldap==2.3.13

see troubles with newer release in 
http://stackoverflow.com/questions/6475118/python-ldap-os-x-10-6-and-python-2-6

TODO
====

make it work on halios (pb version python-ldap)

server en argument

documentation

pas de diactrique dans ldap

EVOLUTIONS
==========

$Id$

$URL$

- fplod 20120405

  * reprise dans le cadre de superbib aeres

- fplod 20111109T103458Z cratos (Linux)

  * reprise

    voici tous les champs::

    ["cn: ['Adel Ammar (S. Thiria)']", 
     "objectClass: ['inetLocalMailRecipient', 'person', 'organizationalPerson', 'inetOrgPerson', 'loceanPersonne', 'posixAccount', 'top']", 
     "uidNumber: ['36310']", 
     "street: ['LOCEAN']", 
     "uid: ['aalod']", 
     "title: ['http://www.locean-ipsl.upmc.fr/photo.jpg']", 
     "mailLocalAddress: ['aalod@locean-ipsl.upmc.fr']", 
     "postalCode: ['75252 PARIS Cedex 05']", 
     "mail: ['aalod@locean-ipsl.upmc.fr', 'aalod@lodyc.jussieu.fr', 'Ammar.Adel@locean-ipsl.upmc.fr', 'Ammar.Adel@lodyc.jussieu.fr', 'Ammar@lodyc.jussieu.fr', 'Ammar@locean-ipsl.upmc.fr', 'Adel.Ammar@locean-ipsl.upmc.fr', 'Adel.Ammar@lodyc.jussieu.fr']", 
      "postalAddress: ['4 place Jussieu']", 
      "description: ['S. Thiria']", 
      "loginShell: ['/bin/tcsh']", 
      "gidNumber: ['1664']", 
      "employeeNumber: ['44']", 
      "mailForwardingAddress: ['Adel.Ammar@locean-ipsl.upmc.fr']", 
      "loceanAnnuaire: ['44']", 
      "displayName: ['Adel.Ammar']", 
      "roomNumber: ['Bureau XXX, Tour 45']", 
      "loceanPhotoUrl: ['http://www.locean-ipsl.upmc.fr/photo.jpg']", 
      "carLicense: ['Thiria']", 
      "mailHost: ['locean-ipsl.upmc.fr']", 
      "gecos: ['Adel Ammar (S. Thiria)']", 
      "sn: ['Ammar']", 
      "homeDirectory: ['/usr/home/aalod']", 
      "givenName: ['Adel']", 
      "uid: ['abelod']", "objectClass: ['posixAccount', 'person', 'organizationalPerson', 'inetOrgPerson', 'loceanPersonne', 'top', 'inetLocalMailRecipient']", "uidNumber: ['36337']", "street: ['LOCEAN']", 
    
- fplod 20110617T080312Z cratos.locean-ipsl.upmc.fr (Linux)

  * no more key error

- fplod 20110616T144623Z cratos.locean-ipsl.upmc.fr (Linux)

  * creation 
    cf. http://www.ibm.com/developerworks/aix/library/au-ldap_crud/
    cf. http://www.packtpub.com/article/python-ldap-applications-ldap-opearations

"""

import sys
import os
from os.path import dirname, basename
import glob
from optparse import OptionParser

import ldap

import itertools

ldap_host = 'nestor.locean-ipsl.upmc.fr'
def get_option_parser ():
    """parse CLI arguments

           :returns: parser
          :rtype: :class:`optparse.OptionParser`
    """

    parser = OptionParser('%prog [--verbose ]')
    parser.add_option ('-V', '--verbose',
        help='produce verbose output',
        action='store_true',
        default=False,
        dest='is_verbose')

    return parser

def readldap(ildap, baseDN, searchScope, searchFilter, is_verbose):
    """
    read LPAP 

    return people dictionnary sn: uid: givenName:  mailForwardingAddress: uidNumber
    """

    retrieveAttributes = ['uid', 'sn', 'givenName', 'mailForwardingAddress', 'uidNumber']
    keys_for_all = []
    values_for_all = [] 
    ldap_result_id = ildap.search_s(baseDN, searchScope, searchFilter, retrieveAttributes)
    for ldap_result_one in ldap_result_id:
        if retrieveAttributes:
            values_for_one = []
            attrib_dict = ldap_result_one[1]
            keys_for_one = attrib_dict.keys()
            for key in attrib_dict.keys():
                values_for_one.append(attrib_dict[key][0])
            keys_for_all.append(attrib_dict['uid'][0])
            values_for_all.append(dict(itertools.izip(keys_for_one, values_for_one)))

            if is_verbose == True:
	        # pour voir la derniere personne ajoute
                print values_for_all[-1]

    # populate dictonnary
    people = dict(itertools.izip(keys_for_all, values_for_all))

    if is_verbose == True:
        print attrib_dict.keys()
        # vu le 20120427 avec retrieveAttributes = ['*']
        # ['uid', 'objectClass', 'uidNumber', 'sambaAcctFlags', 'street', 'cn', 'employeeType', 'facsimileTelephoneNumber', 'mailLocalAddress', 'sambaPwdMustChange', 'postalCode', 'mail', 'postalAddress', 'departmentNumber', 'loginShell', 'gidNumber', 'mailForwardingAddress', 'telephoneNumber', 'loceanAnnuaire', 'displayName', 'roomNumber', 'loceanPhotoUrl', 'carLicense', 'sambaSID', 'mailHost', 'sn', 'homeDirectory', 'givenName', 'loceanFinLogin']

        #print people.keys()
        #print people['fplod']
        #print people['fplod'].values()

    return people

def ldap_biblio():
    """main
    """

    try:
        parser = get_option_parser ()
        (fromcli, args) = parser.parse_args()
    except IOError, msg:
        parser.error(str(msg))

    is_verbose = fromcli.is_verbose

    print ldap.__version__

    #++if ldap.__version__ == '2.3.13'
    #++l = ldap.initialize(ldap_host)
    #++else 
    l = ldap.open(ldap_host)

    l.protocol_version = ldap.VERSION3
    
    baseDN = 'ou=utilisateurs ,dc=locean-ipsl,dc=upmc,dc=fr'
    searchScope = ldap.SCOPE_SUBTREE

    searchFilter = 'uid=*'

    people_ldap = readldap(l, baseDN, searchScope, searchFilter, is_verbose)

    if is_verbose == True:
        print (' result looking for key fplod: %s ' % people_ldap['fplod'])

    #++ find in dict


# Run main, if called from the command line
if __name__ == '__main__':
    ldap_biblio()
